###########################################################################
# Procedure to reconfigure the display style of the selected item.        #
# It is called whenever a button is invoked to change the "colour" or     #
# "fillstyle" of the selected item.                                       #
###########################################################################
proc Change_Selected_Appearance {} {

# Allow access to global vars controlling "Attributes"
    global _COLOUR _LINE_WIDTH _STYLE _NITEM

# Only allow the following to be invoked if an item has been created :
# ($_NITEM > 0).
    if {$_NITEM>=1} {
# Get a list of all the tags of selected item, and identify item-type
        set tagList [.can.c1 gettags selected]
        set type [.can.c1 type selected]

        set comments [lindex [lindex $tagList 1] 3]

        set url [lindex [lindex $tagList 1] 4]

# Find out how many elements in the list 
        set elements [llength $tagList]

# Delete all but the first tag (items index)
        set item_Index [lindex $tagList 0]

# Remove all the tags from selected item except its index
        for {set a [expr ($elements-1)]} {$a>=1} {incr a -1} {
            set tagToDelete [lindex $tagList $a]
            .can.c1 dtag $item_Index $tagToDelete
        }

# If "_STYLE" is currently on "outline", redisplay the item in this style
# Else display it filled
        if {$_STYLE=="outline"} {
            if {$type=="polygon" || $type=="line"} {
                set itemCoords [.can.c1 coords $item_Index]
                eval ".can.c1 delete $item_Index"
                eval ".can.c1 create line $itemCoords -fill $_COLOUR \
                    -width $_LINE_WIDTH -tags $item_Index"
            } else {
                eval ".can.c1 itemconfigure $item_Index \
                    -outline $_COLOUR -fill {} -width $_LINE_WIDTH"
            }
        } else {
            if {$type=="polygon" || $type=="line"} {
                set itemCoords [.can.c1 coords $item_Index]
                eval ".can.c1 delete $item_Index"
                eval ".can.c1 create polygon $itemCoords \
                    -fill $_COLOUR -tags $item_Index"
            } else {
                eval ".can.c1 itemconfigure $item_Index \
                    -outline {} -fill $_COLOUR"
            }
        }

# Set list to hold the relevant values of "Attributes" for the item
        if {$type=="polygon" || $type=="line"} {
            set attributes [list $type $_COLOUR $_LINE_WIDTH  \
                $comments $url]
        } else {
            if {$_STYLE=="outline"} {
                set attributes [list $type $_COLOUR $_LINE_WIDTH \
                    $comments $url]
            } else {
                set attributes [list $type $_COLOUR 0 $comments $url]
            }
        }

# Add these to the list of tags
        .can.c1 addtag $attributes withtag $item_Index
# Replace tag "selected" to item so it can be manipulated further
        .can.c1 addtag selected withtag $item_Index
    }
}

#--------------------------------------------------------------------#

#############################################################################
# This procedure is called every time an item is created or altered.        #
# It is parsed a list containing the item tag_index, and depending on the   #
# various options, the correct tags will be set/reset, to hold information  #
# on the item, for further alterations or for storing.                      #
# Arguments : 1. This will hold the list of attributes for newly created    #
#                items.                                                     #
#             2. Items index, so it can be referenced.                      #
#############################################################################
proc Item_Tags {attributes itemIndex} {

    upvar 1 $attributes listOfTags

    global _COLOUR _LINE_WIDTH _STYLE _CHOICE

# Identify the item type
    set type [.can.c1 type $itemIndex]

# When the item is created it should have the tags in a certain
# order.

    set listOfTags [list $type $_COLOUR $_LINE_WIDTH {} {}]
}
