##########################################################################
# This file contains the binding for <BP-1> inside a coordinate point    #
# for deleting the selected point on a polygon.  It then amends the      #
# coordinate list and reselects the item with a bounding-box around it.  #
# Also, the altered item is automatically reselected on <BR-1>.          #
##########################################################################

proc Delete_Poly_Point {} {

    .can.c1 bind copt <ButtonPress-1> {

# When the user invokes the <BP-1> binding, identify the coordinate list 
# of the selected shape, and store it in a variable.
        set coords [.can.c1 coords selected]
        set lengthCoords [expr ([llength $coords]-1)]

# Give the tag "pointtoDelete" to the closest coordinate-point
# to the cursor location
        catch {
            .can.c1 addtag pointtoDelete closest \
                [.can.c1 canvasx %x] [.can.c1 canvasy %y] 1 "withtag copt"
        }

# Set variables to hold the coordinates of all points on either side of the
# selected one.  These will be used to create a new coordinate list
        set ptsPre ""; set ptsPost ""

# Get a point-index for the chosen point, and split these into
# x and y coordinates
        set delPtCoords [.can.c1 coords pointtoDelete]

# Split the coordinates for the chosen point into x and y respectively.
        set delPtCoords_x [lindex $delPtCoords 0]
        set delPtCoords_y [lindex $delPtCoords 1]

# Search the list of coordinates for the shape to identify which point
# has been chosen
        set index1 [lsearch $coords $delPtCoords_x]
        set index2 [lsearch $coords $delPtCoords_y]

# Lsearch locates the first item in the list with the pattern given.
# If there is a coordinate sharing either the same x or y value, this will
# be selected as matching.  So if the index values are not next to each
# other in the list, the following 'if' statement compares the corresponding
# coordinate value, locating which point has been chosen.
        if {[expr ($index2-1)]!=$index1} {
            if {$delPtCoords_x==[lindex $coords [expr ($index2-1)]]} {
                set index1 [expr ($index2-1)]
            } else  {
                set index2 [expr ($index1+1)]
            } 
        }

# If the point to be deleted is the first point in the coordinate list,
# then the last point must be removed from the list.  Also, the coordinates
# of the point before the last must be inserted as the first two list items.
# Else arrange for the coordinates of the point selected to be removed from
# variable holding the coordinate list.
        if {$index1==0} {
            set newx [lindex $coords [expr ($lengthCoords-3)]]
            set newy [lindex $coords [expr ($lengthCoords-2)]]
            set coords "$newx $newy \
                [lrange $coords 2 [expr ($lengthCoords-2)]]"
        } else {
            set ptsPre [lrange $coords 0 [expr ($index1-1)]]
            set ptsPost [lrange $coords [expr ($index2+1)] $lengthCoords]

            set coords "$ptsPre $ptsPost"
        }

# Set a list to hold the Tags of the selected shape, and from this extract
# its attributes
        set tagList [.can.c1 gettags selected]
        set itemIndex [lindex $tagList 0]

        set attributes [lindex $tagList 1]
        set type [lindex $attributes 0]
        set itemColour [lindex $attributes 1]
        set itemWidth [lindex $attributes 2]

# Delete the item that has been altered, and the 'coordinate points'
        .can.c1 delete selected copt

# Draw the altered item in the same style as it was
        if {$type=="polygon"} {
            eval ".can.c1 create $type $coords -fill $itemColour \
                -tags $itemIndex"
        } else {
            eval ".can.c1 create $type $coords -width $itemWidth \
                -fill $itemColour -tags $itemIndex"
        }

# Give the altered shape the tag containing its attributes
        .can.c1 addtag $attributes withtag $itemIndex
}

#---------------------------------------------------------------------------#

# Create the binding to automatically select the altered shape and reset
# the bindings to their defaults.
    bind .can.c1 <ButtonRelease-1> {
# Since a new shape has been created it must be selected
        Auto_Select $itemIndex

# Reset the global radiobutton variable for the create/edit options
        set _CHOICE ""

# And call the central procedure to reset everything to the defaults
        Control ""
    }
}
